@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "resulttextview.h"
 #include <QDebug>
 #include <QScroller>
@@ -290,7 +294,7 @@ void ResultTextView::pinchTriggered(QPinchGesture *pinch)
         break;
     }
     case Qt::GestureCanceled: {
-        //Q_ASSERT(false);
+        Q_ASSERT(false);
         break;
     }
     case Qt::GestureFinished: {
@@ -300,7 +304,7 @@ void ResultTextView::pinchTriggered(QPinchGesture *pinch)
         break;
     }
     default: {
-        //Q_ASSERT(false);
+        Q_ASSERT(false);
         break;
     }
     }//switch
