@@ -1,31 +1,59 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>MainWidget</name>
     <message>
-        <location filename="../src/mainwidget.cpp" line="166"/>
+        <location filename="../src/mainwidget.cpp" line="115"/>
         <source>No text recognized</source>
         <translation>未识别到文字</translation>
     </message>
     <message>
-        <location filename="../src/mainwidget.cpp" line="214"/>
+        <location filename="../src/mainwidget.cpp" line="166"/>
+        <source>Recognize language</source>
+        <translation>识别语言</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="169"/>
+        <source>Simplified Chinese</source>
+        <translation>简体中文</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="169"/>
+        <source>English</source>
+        <translation>英文</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="169"/>
+        <source>Traditional Chinese</source>
+        <translation>繁体中文</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="204"/>
         <source>Copy text</source>
         <translation>复制文字</translation>
     </message>
     <message>
-        <location filename="../src/mainwidget.cpp" line="221"/>
+        <location filename="../src/mainwidget.cpp" line="210"/>
         <source>Save as TXT</source>
         <translation>保存为TXT</translation>
     </message>
     <message>
-        <location filename="../src/mainwidget.cpp" line="273"/>
-        <location filename="../src/mainwidget.cpp" line="314"/>
+        <location filename="../src/mainwidget.cpp" line="236"/>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>撤销 (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="247"/>
+        <source>Redo (Ctrl+Shift+Z)</source>
+        <translation>重做 (Ctrl+Shift+Z)</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwidget.cpp" line="294"/>
+        <location filename="../src/mainwidget.cpp" line="335"/>
         <source>Recognizing</source>
         <translation>正在识别</translation>
     </message>
     <message>
-        <location filename="../src/mainwidget.cpp" line="514"/>
+        <location filename="../src/mainwidget.cpp" line="563"/>
         <source>Copied</source>
         <translation>已复制</translation>
     </message>
@@ -64,9 +92,9 @@
 <context>
     <name>Widget</name>
     <message>
-        <location filename="../src/mainwidget.cpp" line="262"/>
+        <location filename="../src/mainwidget.cpp" line="283"/>
         <source>Tips: The clearer the image is, the more accurate the text is</source>
         <translation>温馨提示：图像越简洁清晰，识别越准确</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
